==> blue2-xplore-booking-plugin-1.2.4-4787a6.tar: assets/routes/ChooseJourney.js <==
import React, { Component } from 'react';
import axios from 'axios';
import Loader from 'react-loader-spinner';
import { AVAILABLE_JOURNEYS } from './../config/endpoints';
import { connect } from 'react-redux';
import { getTotalSeatsFromCart } from '../redux/selectors';
import { addJourney } from '../redux/actions';
import moment from 'moment';
import NoResults from '../components/ChooseTickets/NoResults';
import posed from 'react-pose';
import { toast } from 'react-toastify';

const Container = posed.div({
    enter: { staggerChildren: 50 }
});

const AnimatedDiv = posed.div({
    enter: { x: 0, opacity: 1 },
    exit: { x: 25, opacity: 0 }
});

class ChooseJourney extends Component {
    constructor(props) {
        super(props);

        this.state = {
            journeys: null,
            loading: true,
            showReturn: false
        };
    }

    componentDidMount() {
        const { journeyType, depart, departureDate, returnDate, totalSeats } = this.props;
        const departFormatted = this.formatDate(departureDate);
        const returnFormatted = this.formatDate(returnDate);
        const body = { journeyType, depart, departFormatted, returnFormatted, totalSeats };

        axios
            .get(AVAILABLE_JOURNEYS, {
                params: body
            })
            .then(response => {
                if (response.status !== 200) {
                    console.log(response);
                    toast.error('An error occured fetching journeys');
                    return;
                }
                this.setState({
                    journeys: JSON.parse(response.data),
                    loading: false
                });
            })
            .catch(error => {
                toast.error('An error occured fetching journeys');
                console.error('Fetch Journeys: ', error);
                this.setState({ loading: false });
            });
    }

    formatDate = date => {
        return moment(date).format('DD-MM-YYYY');
    };

    journeyList = (journeys, direction) => {
        let items = [];
        for (let [key, value] of Object.entries(journeys)) {
            items.push(
                <AnimatedDiv className="journey" key={key}>
                    <p dangerouslySetInnerHTML={{ __html: value.title }} />
                    <button
                        onClick={() => {
                            this.props.addJourney({ ...value, slug: key }, direction);
                            if (direction === 'outbound' && this.state.journeys.inbound) {
                                this.setState({ showReturn: true });
                            }
                        }}>
                        Add Journey
                    </button>
                </AnimatedDiv>
            );
        }
        return items;
    };

    render() {
        return (
            <div className="choose-journey">
                <h1>{!this.state.showReturn ? 'Outbound Journey' : 'Inbound Journey'}</h1>
                {this.state.loading && (
                    <Loader type="Oval" width={50} height={50} color="#088584" />
                )}
                {!this.state.loading && this.state.journeys === null && <NoResults />}

                {this.state.journeys && (
                    <Container>
                        {this.state.journeys.outbound && !this.state.showReturn && (
                            <>{this.journeyList(this.state.journeys.outbound, 'outbound')}</>
                        )}
                        {this.state.journeys.inbound && this.state.showReturn && (
                            <>{this.journeyList(this.state.journeys.inbound, 'inbound')}</>
                        )}
                    </Container>
                )}
            </div>
        );
    }
}

const mapStateToProps = state => {
    const { journeyType, depart, departureDate, returnDate } = state.cart;
    const totalSeats = getTotalSeatsFromCart(state);
    return {
        journeyType,
        depart,
        departureDate,
        returnDate,
        totalSeats
    };
};

//TODO: Add journey action to be connected
export default connect(
    mapStateToProps,
    { addJourney }
)(ChooseJourney);

==> blue2-xplore-booking-plugin-1.2.6-508655.tar: assets/routes/ChooseJourney.js <==
import React, { Component } from 'react';
import axios from 'axios';
import Loader from 'react-loader-spinner';
import { AVAILABLE_JOURNEYS } from './../config/endpoints';
import { connect } from 'react-redux';
import { getTotalSeatsFromCart } from '../redux/selectors';
import { addJourney } from '../redux/actions';
import moment from 'moment';
import NoResults from '../components/ChooseTickets/NoResults';
import posed from 'react-pose';
import { toast } from 'react-toastify';

const Container = posed.div({
    enter: { staggerChildren: 50 }
});

const AnimatedDiv = posed.div({
    enter: { x: 0, opacity: 1 },
    exit: { x: 25, opacity: 0 }
});

class ChooseJourney extends Component {
    constructor(props) {
        super(props);

        this.state = {
            journeys: null,
            loading: true,
            showReturn: false
        };
    }

    componentDidMount() {
        const { journeyType, depart, departureDate, returnDate, totalSeats } = this.props;
        const departFormatted = this.formatDate(departureDate);
        const returnFormatted = this.formatDate(returnDate);
        const body = { journeyType, depart, departFormatted, returnFormatted, totalSeats };

        axios
            .get(AVAILABLE_JOURNEYS, {
                params: body
            })
            .then(response => {
                if (response.status !== 200) {
                    console.log(response);
                    toast.error('An error occured fetching journeys');
                    return;
                }
                this.setState({
                    journeys: JSON.parse(response.data),
                    loading: false
                });
            })
            .catch(error => {
                toast.error('An error occured fetching journeys');
                console.error('Fetch Journeys: ', error);
                this.setState({ loading: false });
            });
    }

    formatDate = date => {
        return moment(date).format('DD-MM-YYYY');
    };

    journeyList = (journeys, direction) => {
        const { outbound, inbound } = this.props;
        let items = [];
        const comparison = direction === 'outbound' ? outbound : inbound;

        for (let [key, value] of Object.entries(journeys)) {
            const selected = comparison && value.id === comparison.id;
            items.push(
                <AnimatedDiv className="journey" key={key}>
                    <h2 className="time">
                        {value.departure_time} - {value.arrival_time}
                    </h2>
                    <hr />
                    <div className="internal">
                        <div className="info">
                            <p className="duration">1.30h</p>
                            <p>Departure, to Arrival</p>
                        </div>
                        <button
                            className="dark"
                            disabled={selected}
                            onClick={() => {
                                this.props.addJourney({ ...value, slug: key }, direction);
                                if (direction === 'outbound' && this.state.journeys.inbound) {
                                    this.setState({ showReturn: true });
                                }
                            }}>
                            {selected ? `Added` : `Add Journey`}
                        </button>
                    </div>
                </AnimatedDiv>
            );
        }
        return items;
    };

    render() {
        return (
            <div className="choose-journey">
                <h1>{!this.state.showReturn ? 'Outbound Journey' : 'Inbound Journey'}</h1>
                {this.state.loading && (
                    <Loader type="Oval" width={50} height={50} color="#088584" />
                )}
                {!this.state.loading && this.state.journeys === null && <NoResults />}

                {this.state.journeys && (
                    <Container>
                        {this.state.journeys.outbound && !this.state.showReturn && (
                            <>{this.journeyList(this.state.journeys.outbound, 'outbound')}</>
                        )}
                        {this.state.journeys.inbound && this.state.showReturn && (
                            <>{this.journeyList(this.state.journeys.inbound, 'inbound')}</>
                        )}
                    </Container>
                )}
            </div>
        );
    }
}

const mapStateToProps = state => {
    const { journeyType, depart, departureDate, returnDate, outbound, inbound } = state.cart;
    const totalSeats = getTotalSeatsFromCart(state);
    return {
        journeyType,
        depart,
        departureDate,
        returnDate,
        totalSeats,
        outbound,
        inbound
    };
};

export default connect(
    mapStateToProps,
    { addJourney }
)(ChooseJourney);
